-------------------------------------------------------------------------
--
-- This file creates the catalog views for the object-relational
-- extensions to DB2 UDB v7.  Since the views cannot be created in
-- the proper SYSCAT schema, the names are mapped as follows:
--    SYSCAT views are created in the OBJCAT schema
--    SYSSTAT views are created in the OBJSTAT schema
--
-- Usage: Execute this file with the command:
--   db2 -tvf objcat.db2
--
-- To execute the statements in the file, you must have SYSADM or DBADM
-- authority.
--
-------------------------------------------------------------------------

-------------------------------------------------------------------------
-- Catalog views

create schema objcat ;

-- OBJCAT.TRANSFORMS
create view objcat.transforms
  ( typeid, typeschema, typename, groupname,
    funcid, funcschema, funcname, specificname, transformtype,
    format, maxlength, origin, remarks ) as
  select d.typeid, d.schema, d.name, t.groupname,
    f.function_id, f.schema, f.name, f.specific, 'FROM SQL',
    t.fromsql_format, t.fromsql_length, t.origin, t.remarks
  from   sysibm.systransforms as t,
         sysibm.sysdatatypes  as d,
         sysibm.sysfunctions  as f
  where  t.typeid    = d.typeid
    and  t.fromsql_funcid = f.function_id
  union all
  select d.typeid, d.schema, d.name, t.groupname,
    f.function_id, f.schema, f.name, f.specific, 'TO SQL',
    t.tosql_format, cast (NULL as integer), t.origin, t.remarks
  from   sysibm.systransforms as t,
         sysibm.sysdatatypes  as d,
         sysibm.sysfunctions  as f
  where  t.typeid    = d.typeid
    and  t.tosql_funcid = f.function_id
  ;

-- OBJCAT.INDEXEXTENSIONDEP
create view objcat.indexextensiondep 
    (ieschema, iename, btype, bschema, bname, tabauth) 
 as select 
     dschema, dname, btype, bschema, bname, tabauth 
 from sysibm.sysdependencies 
 where dtype = 'X';


-- OBJCAT.INDEXEXTENSIONMETHODS
create view objcat.indexextensionmethods 
    (methodname, methodid, ieschema, iename, rangefuncschema, 
     rangefuncname, rangespecificname, filterfuncschema, filterfuncname, 
     filterspecificname, remarks) 
 as select 
     methodname, methodid, ieschema, iename, rtfuncschema,
     rtfuncname, rtspecificname, cwfuncschema, cwfuncname,
     cwspecificname, remarks
 from sysibm.sysindexextensionmethods;


-- OBJCAT.INDEXEXTENSIONPARMS
create view objcat.indexextensionparms 
    (ieschema, iename, ordinal, parmname, typeschema, typename, 
     length, scale, parmtype, codepage) 
 as select 
     ieschema, iename, ordinal, parmname, typeschema, typename,
     length, scale, parmtype, codepage
 from sysibm.sysindexextensionparms; 


-- OBJCAT.INDEXEXTENSIONS
create view objcat.indexextensions 
    (ieschema, iename, definer, create_time, keygenfuncschema,
     keygenfuncname, keygenspecificname, text, remarks) 
  as select 
     ieschema, iename, definer, create_time, ktfuncschema,
     ktfuncname, ktspecificname, text, remarks
 from sysibm.sysindexextensions;


-- Catalog view indexes needs to be updated for extended index
create view objcat.indexes 
    (indschema, indname, definer, tabschema, tabname, colnames, 
     uniquerule, made_unique, colcount, unique_colcount, 
     indextype, entrytype, pctfree, iid, nleaf, nlevels,  
     firstkeycard, first2keycard, first3keycard, first4keycard, 
     fullkeycard, clusterratio, clusterfactor, sequential_pages, 
     density, user_defined, system_required, create_time, 
     stats_time, page_fetch_pairs, minpctused, reverse_scans, 
     internal_format, ieschema, iename, iearguments,  remarks) 
 as select 
     creator, name, definer, tbcreator, tbname, colnames, 
     uniquerule, made_unique, colcount, unique_colcount, 
     indextype, entrytype, pctfree, iid, nleaf, nlevels, 
     firstkeycard, first2keycard, first3keycard,first4keycard, 
     fullkeycard, clusterratio, clusterfactor, sequential_pages, 
     density, user_defined, system_required, create_time, 
     stats_time end, page_fetch_pairs,  minpctused, reverse_scans, 
     internal_format, ieschema, iename, iearguments, remarks 
 from sysibm.sysindexes;

-- OBJCAT.PREDICATESPECS
create view objcat.predicatespecs 
     (funcschema, funcname, specificname, funcid, specid, contextop, 
      contextexp, filtertext) 
 as select 
     fn.schema, fn.name, fn.specific, ps.funcid, ps.specid, ps.contextop, 
     ps.contextexp, CAST(ps.filtertext as CLOB(32K))
 from sysibm.sysfunctions fn, sysibm.syspredicatespecs ps
 where fn.function_id = ps.funcid;

-- OBJCAT.INDEXEXPLOITRULES
create view objcat.indexexploitrules 
     (funcid, specid, ieschema, iename, ruleid, searchmethodid, 
      searchkey, searchargument) 
 as select funcid, specid, ieschema, iename, ruleid, searchmethodid, 
      searchkey, searchargument
 from sysibm.sysindexexploitrules;


-------------------------------------------------------------------------

grant select on table objcat.transforms to public;
grant select on table objcat.indexextensiondep to public;
grant select on table objcat.indexextensionmethods to public;
grant select on table objcat.indexextensionparms to public;
grant select on table objcat.indexextensions to public;
grant select on table objcat.indexes to public;
grant select on table objcat.predicatespecs to public;
grant select on table objcat.indexexploitrules to public;

commit;
connect reset;
terminate;
