/******************************************************************************
** 
** Source File Name: db2ApiDf
** 
** (C) COPYRIGHT International Business Machines Corp. 1987, 1997
** All Rights Reserved
** Licensed Materials - Property of IBM
** 
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
** 
** Function = Include File defining:
**              Environment Commands - Constants
**              Environment Commands - Structures
**              Environment Commands - Function Prototypes
**              Environment Commands - Labels for SQLCODES
** 
** Operating System: LINUX
** 
*******************************************************************************/
#ifndef SQL_H_DB2APIDF
#define SQL_H_DB2APIDF

#ifdef __cplusplus
extern "C" {
#endif

/* Note: _SQLOLDCHAR defaults to 'char'.  See sqlsystm.h for details.         */

#include "sqlsystm.h"                  /* System dependent defines  */

/* Required Include Files */

#include "sql.h"                       /* Includes sqlsystm & sqlca */
#include "sqlda.h"
#include "sqlmon.h"
#include "sqlaprep.h"
#include "sqlutil.h"
#include <stddef.h>                    /* needed for offsetof */


/* Version, Release PTF identifier                                            */
#define db2Version6Prior SQL_RELPRE6                 /* Pre Version 6.1.0.0   */
#define db2Version610    SQL_REL6100                 /* Version 6.1.0.0       */
#define db2Version710    SQL_REL7100                 /* Version 7.1.0.0       */

/* Type definition names                                                      */
typedef sqluint32 db2Uint32;                         /* 32 bit unsigned int   */
typedef sqlint32  db2int32;                          /* 32 bit signed int     */
typedef sqluint16 db2Uint16;                         /* 16 bit unsigned int   */
typedef sqlint16  db2int16;                          /* 16 bit signed int     */

/******************************************************************************
** Structure db2Char
** 
** Description:
**     pioData  -- Pointer to character data.
**              -- If NULL, no data will be returned.
** 
**     iLength  -- Input:  Size of the pData buffer.
** 
**     oLength  -- Output: Length of valid data in pData.
**              -- If the output data was truncated, this will be set to
**                 the complete size before truncation
*******************************************************************************/
typedef SQL_STRUCTURE db2Char
{
   char            *pioData;           /* Character data                      */
   db2Uint32       iLength;            /* I:  Length of pioData               */
   db2Uint32       oLength;            /* O:  Untruncated length of data      */
} db2Char;

/******************************************************************************
** Load Query Structures and Constants
*******************************************************************************/

/* Possible values for "iStringType"                                          */
#define DB2LOADQUERY_TABLENAME         0         /* Tablename specified       */
#define DB2LOADQUERY_TEMPPATHNAME      1

/* Possible values for "iShowLoadMessages"                                    */
#define DB2LOADQUERY_SHOW_ALL_MSGS     0         /* Show ALL LOAD messages    */
#define DB2LOADQUERY_SHOW_NO_MSGS      1         /* Show NO LOAD messages     */
#define DB2LOADQUERY_SHOW_NEW_MSGS     2         /* Show only NEW LOAD        */
                                                 /* messages                  */

/* Possible values for "oWhichPhase"                                          */
#define DB2LOADQUERY_LOAD_PHASE        1         /* Load Phase                */
#define DB2LOADQUERY_BUILD_PHASE       2         /* Build Phase               */
#define DB2LOADQUERY_DELETE_PHASE      3         /* Delete Phase              */

/* Load Query Output Structure                                                */
typedef SQL_STRUCTURE db2LoadQueryOutputStruct
{
   db2Uint32       oRowsRead;          /* Rows Read                           */
   db2Uint32       oRowsSkipped;       /* Rows Skipped                        */
   db2Uint32       oRowsCommitted;     /* Rows Committed                      */
   db2Uint32       oRowsLoaded;        /* Rows Loaded                         */
   db2Uint32       oRowsRejected;      /* Rows Rejected                       */
   db2Uint32       oRowsDeleted;       /* Rows Deleted                        */
   db2Uint32       oCurrentIndex;      /* Current Index (BUILD PHASE)         */
   db2Uint32       oNumTotalIndexes;   /* Total # of Indexes to build (BUILD  */
                                       /* PHASE)                              */
   db2Uint32       oCurrentMPPNode;    /* Node being queried (MPP only)       */
   db2Uint32       oLoadRestarted;     /* Load Restart indicator              */
   db2Uint32       oWhichPhase;        /* Phase of queried Load               */
   db2Uint32       oWarningCount;      /* Warning Count                       */
} db2LoadQueryOutputStruct;

/* Load Query Parameter Structure                                             */
typedef SQL_STRUCTURE db2LoadQueryStruct
{
   db2Uint32       iStringType;        /* Type of piString                    */
   char            *piString;          /* Name to query                       */
   db2Uint32       iShowLoadMessages;  /* Level of Load message reporting     */
   struct db2LoadQueryOutputStruct *poOutputStruct; /* Load Query Output      */
                                       /* Structure                           */
   char            *piLocalMessageFile; /* Message File                       */
} db2LoadQueryStruct;

SQL_API_RC SQL_API_FN                  /* Load Query                          */
  db2LoadQuery (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Generic Load Query Parameter Structure                                     */
typedef SQL_STRUCTURE db2gLoadQueryStruct
{
   db2Uint32       iStringType;        /* Type of piString                    */
   db2Uint32       iStringLen;         /* Length in bytes of piString         */
   char            *piString;          /* Name to query                       */
   db2Uint32       iShowLoadMessages;  /* Level of Load message reporting     */
   struct db2LoadQueryOutputStruct *poOutputStruct; /* Load Query Output      */
                                       /* Structure                           */
   db2Uint32       iLocalMessageFileLen; /* Length in bytes of message file   */
                                       /* variable                            */
   char            *piLocalMessageFile; /* Message File                       */
} db2gLoadQueryStruct;

SQL_API_RC SQL_API_FN                  /* Generic Load Query                  */
  db2gLoadQuery (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/******************************************************************************
** Open History Scan Definitions
*******************************************************************************/

/* Values for db2HistoryOpen - iCallerAction                                  */
#define DB2HISTORY_LIST_HISTORY        0
#define DB2HISTORY_LIST_BACKUP         1
#define DB2HISTORY_LIST_ROLLFORWARD    2
#define DB2HISTORY_LIST_RUNSTATS       3
#define DB2HISTORY_LIST_REORG          4
#define DB2HISTORY_LIST_ALT_TABLESPACE 5
#define DB2HISTORY_LIST_DROPPED_TABLE  6
#define DB2HISTORY_LIST_LOAD           7
#define DB2HISTORY_LIST_REN_TABLESPACE 8
#define DB2HISTORY_LIST_CRT_TABLESPACE 9

/* db2HistoryOpen input struct                                                */
typedef SQL_STRUCTURE db2HistoryOpenStruct
{
   char            *piDatabaseAlias;   /* DB to fetch history from            */
   char            *piTimestamp;       /* Since this timestamp                */
   char            *piObjectName;      /* Entries containing this object      */
   db2Uint32       oNumRows;           /* # of entries matching search        */
   db2Uint32       oMaxTbspaces;       /* Max. # of tablespace names stored   */
                                       /* with ANY history entry              */
   db2Uint16       iCallerAction;      /* Caller action                       */
   db2Uint16       oHandle;            /* Handle for this scan                */
} db2HistoryOpenStruct;

/* db2HistoryOpenScan - API                                                   */
SQL_API_RC SQL_API_FN                  /* Open a history file scan            */
  db2HistoryOpenScan (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* In/out parameters                   */
       struct sqlca * pSqlca);         /* SQLCA                               */

/* db2gHistoryOpen input struct                                               */
typedef SQL_STRUCTURE db2gHistoryOpenStruct
{
   char            *piDatabaseAlias;   /* DB to fetch history from            */
   char            *piTimestamp;       /* Since this timestamp                */
   char            *piObjectName;      /* Entries containing this object      */
   db2Uint32       iAliasLen;          /* Length of database alias string     */
   db2Uint32       iTimestampLen;      /* Length of timestamp string          */
   db2Uint32       iObjectNameLen;     /* Length of object name string        */
   db2Uint32       oNumRows;           /* # of entries matching search        */
   db2Uint32       oMaxTbspaces;       /* Max. # of tablespace names stored   */
                                       /* with ANY history entry              */
   db2Uint16       iCallerAction;      /* Caller action                       */
   db2Uint16       oHandle;            /* Handle for this scan                */
} db2gHistoryOpenStruct;

/* db2gHistoryOpenScan - Generic API                                          */
SQL_API_RC SQL_API_FN                  /* Open a history file scan            */
  db2gHistoryOpenScan (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* In/out parameters                   */
       struct sqlca * pSqlca);         /* SQLCA                               */

/******************************************************************************
** Fetch Next History Entry Definititions
*******************************************************************************/

/* Structure db2HistoryEID                                                    */
typedef SQL_STRUCTURE db2HistoryEID
{
   SQL_PDB_NODE_TYPE ioNode;           /* Node number                         */
   db2Uint32       ioHID;              /* Local history file entry ID         */
} db2HistoryEID;

/* Max Sizes of db2HistoryDataStruct db2Char fields                           */
/* NOTE:  These lengths do not include NULL terminators                       */
#define DB2HISTORY_TIMESTAMP_SZ        14
#define DB2HISTORY_SEQNUM_SZ           3
#define DB2HISTORY_OBJPART_SZ          (DB2HISTORY_TIMESTAMP_SZ + DB2HISTORY_SEQNUM_SZ)
#define DB2HISTORY_LOGFILE_SZ          12
#define DB2HISTORY_ID_SZ               24
#define DB2HISTORY_TABLE_QUAL_SZ       30
#define DB2HISTORY_TABLE_NAME_SZ       128
#define DB2HISTORY_LOCATION_SZ         255
#define DB2HISTORY_COMMENT_SZ          30
#define DB2HISTORY_COMMAND_SZ          SQL_MAX_STMT_SIZ

/* Structure db2HistoryData                                                   */
/*                                                                            */
/* Description:                                                               */
/*      ioHistDataID      -- Eye catcher, must be set to "SQLUHINF"           */
/*                                                                            */
/*      oObjectPart       -- Start time + sequence number                     */
/*                        -- DB2HISTORY_OBJPART_SZ                            */
/*                                                                            */
/*      oEndTime          -- Completion timestamp                             */
/*                        -- DB2HISTORY_TIMESTAMP_SZ                          */
/*                                                                            */
/*      oFirstLog         -- First log file referrenced by event              */
/*                        -- DB2HISTORY_LOGFILE_SZ                            */
/*                                                                            */
/*      oLastLog          -- Last log file referrenced by event               */
/*                        -- DB2HISTORY_LOGFILE_SZ                            */
/*                                                                            */
/*      oID               -- Backup ID (timestamp), or unique table ID        */
/*                        -- DB2HISTORY_ID_SZ                                 */
/*                                                                            */
/*      oTableQualifier   -- Table qualifier                                  */
/*                        -- DB2HISTORY_TABLE_QUAL_SZ                         */
/*                                                                            */
/*      oTableName        -- Table name                                       */
/*                        -- DB2HISTORY_TABLE_NAME_SZ                         */
/*                                                                            */
/*      oLocation         -- Location of object used or produced by event     */
/*                        -- DB2HISTORY_LOCATION_SZ                           */
/*                                                                            */
/*      oComment          -- Text comment                                     */
/*                        -- DB2HISTORY_COMMENT_SZ                            */
/*                                                                            */
/*      oCommandText      -- Command text, or DDL                             */
/*                        -- DB2HISTORY_COMMAND_SZ                            */
/*                                                                            */
/*      oLastLSN          -- Last Log Sequence Number                         */
/*      poEventSQLCA      -- SQLCA returned at event completion               */
/*      poTablespace      -- LIST of tablespace names                         */
/*      iNumTablespaces   -- # of available entries in the poTablespace list  */
/*      oNumTablespaces   -- # of used entries in the poTablespace list       */
/*      oEID              -- Unique history entry ID                          */
/*      oOperation        -- Event type:        DB2HISTORY_TYPE_*             */
/*      oObject           -- Event granularity: DB2HISTORY_GRAN_*             */
/*      oOptype           -- Event details:     DB2HISTORY_OPTYPE_*           */
/*      oStatus           -- Entry status:      DB2HISTORY_STATUS_*           */
/*      oDeviceType       -- Type of oLocation: DB2_MEDIA_*                   */

typedef SQL_STRUCTURE db2HistoryData
{
   char            ioHistDataID[8];    /* Eye catcher = 'SQLUHINF'            */
   db2Char         oObjectPart;        /* Start time + sequence number        */
   db2Char         oEndTime;           /* Completion time of event            */
   db2Char         oFirstLog;          /* First log file                      */
   db2Char         oLastLog;           /* Last log file                       */
   db2Char         oID;                /* Backup ID, or unique table ID       */
   db2Char         oTableQualifier;    /* Table qualifier                     */
   db2Char         oTableName;         /* Table name                          */
   db2Char         oLocation;          /* Location of referrenced object      */
   db2Char         oComment;           /* Text comment                        */
   db2Char         oCommandText;       /* Command text                        */
   SQLU_LSN        oLastLSN;           /* Last log sequence number            */
   db2HistoryEID   oEID;               /* Unique entry ID                     */
   struct sqlca    *poEventSQLCA;      /* Resulting SQLCA of event            */
   struct db2Char  *poTablespace;      /* List of tablespace names            */
   db2Uint32       iNumTablespaces;    /* I: # of available poTablespace      */
                                       /* fields                              */
   db2Uint32       oNumTablespaces;    /* O: # of used poTablespace fields    */
   char            oOperation;         /* Event type                          */
   char            oObject;            /* Operation granularity               */
   char            oOptype;            /* Operation details                   */
   char            oStatus;            /* Status of entry                     */
   char            oDeviceType;        /* Device type of 'location'           */
} db2HistoryData;

/* Values for db2HistoryGetEntry - iCallerAction                              */
#define DB2HISTORY_GET_ENTRY 0     /* Next entry, without command data        */
#define DB2HISTORY_GET_DDL   1     /* ONLY command data from previous fetch   */
#define DB2HISTORY_GET_ALL   2     /* Next entry, with all data               */

/* db2HistoryGetEntry input struct                                            */
typedef SQL_STRUCTURE db2HistoryGetEntryStruct
{
   struct db2HistoryData *pioHistData; /* History entry data area             */
   db2Uint16       iHandle;            /* History scan handle                 */
   db2Uint16       iCallerAction;      /* Caller action                       */
} db2HistoryGetEntryStruct;

/* db2HistoryGetEntry - API                                                   */
SQL_API_RC SQL_API_FN                  /* Fetch the next history file entry   */
  db2HistoryGetEntry (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* In/out parameters                   */
       struct sqlca * pSqlca);         /* SQLCA                               */

/* db2gHistoryGetEntry - Generic API                                          */
SQL_API_RC SQL_API_FN                  /* Fetch the next history file entry   */
  db2gHistoryGetEntry (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* In/out parameters                   */
       struct sqlca * pSqlca);         /* SQLCA                               */

/* History Operations                                                         */
#define DB2HISTORY_OP_CRT_TABLESPACE   'A'
#define DB2HISTORY_OP_BACKUP           'B'
#define DB2HISTORY_OP_LOAD_COPY        'C'
#define DB2HISTORY_OP_DROPPED_TABLE    'D'
#define DB2HISTORY_OP_ROLLFWD          'F'
#define DB2HISTORY_OP_REORG            'G'
#define DB2HISTORY_OP_LOAD             'L'
#define DB2HISTORY_OP_REN_TABLESPACE   'N'
#define DB2HISTORY_OP_DROP_TABLESPACE  'O'
#define DB2HISTORY_OP_QUIESCE          'Q'
#define DB2HISTORY_OP_RESTORE          'R'
#define DB2HISTORY_OP_RUNSTATS         'S'
#define DB2HISTORY_OP_ALT_TABLESPACE   'T'
#define DB2HISTORY_OP_UNLOAD           'U'

/* History Objects                                                            */
#define DB2HISTORY_GRAN_DB             'D'
#define DB2HISTORY_GRAN_TBS            'P'
#define DB2HISTORY_GRAN_TABLE          'T'

/* Backup Optypes                                                             */
#define DB2HISTORY_OPTYPE_OFFLINE      'F'
#define DB2HISTORY_OPTYPE_ONLINE       'N'
#define DB2HISTORY_OPTYPE_INCR_OFFLINE 'I'
#define DB2HISTORY_OPTYPE_INCR_ONLINE  'O'
#define DB2HISTORY_OPTYPE_DELT_OFFLINE 'D'
#define DB2HISTORY_OPTYPE_DELT_ONLINE  'E'

/* Quiesce Optypes                                                            */
#define DB2HISTORY_OPTYPE_SHARE        'S'
#define DB2HISTORY_OPTYPE_UPDATE       'U'
#define DB2HISTORY_OPTYPE_EXCL         'X'
#define DB2HISTORY_OPTYPE_RESET        'Z'

/* Rollforward Optypes                                                        */
#define DB2HISTORY_OPTYPE_EOL          'E'
#define DB2HISTORY_OPTYPE_PIT          'P'

/* Load Optypes                                                               */
#define DB2HISTORY_OPTYPE_INSERT       'I'
#define DB2HISTORY_OPTYPE_REPLACE      'R'

/* Alter Tablespace Optypes                                                   */
#define DB2HISTORY_OPTYPE_ADD_CONT     'C'
#define DB2HISTORY_OPTYPE_REB          'R'

/* History Entry Status Flags                                                 */
#define DB2HISTORY_STATUS_ACTIVE       'A'
#define DB2HISTORY_STATUS_INACTIVE     'I'
#define DB2HISTORY_STATUS_EXPIRED      'E'
#define DB2HISTORY_STATUS_DELETED      'D'
#define DB2HISTORY_STATUS_NC           'N'
#define DB2HISTORY_STATUS_INCMP_ACTV   'a'
#define DB2HISTORY_STATUS_INCMP_INACTV 'i'

/******************************************************************************
** Close History Scan Definititions
*******************************************************************************/

/* db2HistoryCloseScan - API                                                  */
SQL_API_RC SQL_API_FN                  /* Close a history file scan           */
  db2HistoryCloseScan (
       db2Uint32 versionNumber,        /* Database version number             */
       void * piHandle,                /* History scan handle                 */
       struct sqlca * pSqlca);         /* SQLCA                               */


/* db2gHistoryCloseScan - Generic API                                         */
SQL_API_RC SQL_API_FN                  /* Close a history file scan           */
  db2gHistoryCloseScan (
       db2Uint32 versionNumber,        /* Database version number             */
       void * piHandle,                /* History scan handle                 */
       struct sqlca * pSqlca);         /* SQLCA                               */

/******************************************************************************
** Update History Entry Definititions
*******************************************************************************/

/* Update history API input struct                                            */
typedef SQL_STRUCTURE db2HistoryUpdateStruct
{
   char            *piNewLocation;
   char            *piNewDeviceType;
   char            *piNewComment;
   db2HistoryEID   iEID;               /* ID of the entry to be updated       */
} db2HistoryUpdateStruct;

/* db2HistoryUpdate - API                                                     */
SQL_API_RC SQL_API_FN                  /* Update history entry data           */
  db2HistoryUpdate (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* Input parameters                    */
       struct sqlca * pSqlca);         /* SQLCA                               */

/* Update history API input struct                                            */
typedef SQL_STRUCTURE db2gHistoryUpdateStruct
{
   char            *piNewLocation;
   char            *piNewDeviceType;
   char            *piNewComment;
   db2Uint32       iNewLocationLen;
   db2Uint32       iNewDeviceLen;
   db2Uint32       iNewCommentLen;
   db2HistoryEID   iEID;               /* ID of the entry to be updated       */
} db2gHistoryUpdateStruct;

/* db2gHistoryUpdate - Generic API                                            */
SQL_API_RC SQL_API_FN                  /* Update history entry data           */
  db2gHistoryUpdate (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* Input parameters                    */
       struct sqlca * pSqlca);         /* SQLCA                               */

/******************************************************************************
** Precompiler API Related Definitions
*******************************************************************************/

/* Compile SQL Parmeter Structure                                             */
typedef struct db2CompileSqlStruct
{
   db2Uint32       *piSqlStmtLen;      /* SQL statement text length           */
   char            *piSqlStmt;         /* SQL statement text                  */
   db2Uint32       *piLineNum;         /* Source Line Number                  */
   struct sqla_flaginfo *pioFlagInfo;  /* SQL Flagger information             */
   struct sqla_tokens *pioTokenIdArray; /* Token ID Array                     */
   struct sqla_tasks *poTaskArray;     /* Task Array                          */
   db2Uint16       *poSectionNum;      /* Section Number                      */
   db2Uint16       *poSqlStmtType;     /* Type of SQL statement               */
   char            *poBuffer1;         /* 256 byte string buffer 1            */
   char            *poBuffer2;         /* 256 byte string buffer 2            */
   char            *poBuffer3;         /* 256 byte string buffer 3            */
   void            *pioReserved;       /* Reserved                            */
} db2CompileSqlStruct;

/* Generic Compile SQL Parmeter Structure                                     */
typedef struct db2gCompileSqlStruct
{
   db2Uint32       *piSqlStmtLen;      /* SQL statement text length           */
   char            *piSqlStmt;         /* SQL statement text                  */
   db2Uint32       *piLineNum;         /* Source Line Number                  */
   struct sqla_flaginfo *pioFlagInfo;  /* SQL Flagger information             */
   struct sqla_tokens *pioTokenIdArray; /* Token ID Array                     */
   struct sqla_tasks *poTaskArray;     /* Task Array                          */
   db2Uint16       *poSectionNum;      /* Section Number                      */
   db2Uint16       *poSqlStmtType;     /* Type of SQL statement               */
   char            *poBuffer1;         /* 256 byte string buffer 1            */
   char            *poBuffer2;         /* 256 byte string buffer 2            */
   char            *poBuffer3;         /* 256 byte string buffer 3            */
   void            *pioReserved;       /* Reserved                            */
} db2gCompileSqlStruct;

/* Compile SQL API                                                            */
SQL_API_RC SQL_API_FN                  /* Compile an SQL statement            */
  db2CompileSql (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Generic Compile SQL API                                                    */
SQL_API_RC SQL_API_FN                  /* Compile an SQL statement            */
  db2gCompileSql (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Initialization Parmeter Structure                                          */
typedef struct db2InitStruct
{
   db2Uint16       *piProgramNameLength; /* Program name length               */
   char            *piProgramName;     /* Program name                        */
   db2Uint16       *piDbNameLength;    /* Database name length                */
   char            *piDbName;          /* Database name                       */
   db2Uint16       *piDbPasswordLength; /* Password length                    */
   char            *piDbPassword;      /* Password                            */
   db2Uint16       *piBindNameLength;  /* Bindfile name length                */
   char            *piBindName;        /* Bindfile name                       */
   struct sqla_options *piOptionsArray; /* Precompiler options array          */
   db2Uint16       *piPidLength;       /* Precompiler program ID buffer       */
                                       /* length                              */
   struct sqla_program_id *poPrecompilerPid; /* Precompiler program ID        */
} db2InitStruct;

/* Generic Initialization Parmeter Structure                                  */
typedef struct db2gInitStruct
{
   db2Uint16       *piProgramNameLength; /* Program name length               */
   char            *piProgramName;     /* Program name                        */
   db2Uint16       *piDbNameLength;    /* Database name length                */
   char            *piDbName;          /* Database name                       */
   db2Uint16       *piDbPasswordLength; /* Password length                    */
   char            *piDbPassword;      /* Password                            */
   db2Uint16       *piBindNameLength;  /* Bindfile name length                */
   char            *piBindName;        /* Bindfile name                       */
   struct sqla_options *piOptionsArray; /* Precompiler options array          */
   db2Uint16       *piPidLength;       /* Precompiler program ID buffer       */
                                       /* length                              */
   struct sqla_program_id *poPrecompilerPid; /* Precompiler program ID        */
} db2gInitStruct;

/* Initialization API                                                         */
SQL_API_RC SQL_API_FN                  /* Initialize an access plan           */
  db2Initialize (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Generic Initialization SQL API                                             */
SQL_API_RC SQL_API_FN                  /* Initialize an access plan           */
  db2gInitialize (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/******************************************************************************
** Prune Database History Definititions
*******************************************************************************/

/* Values for db2Prune - iCallerAction                                        */
#define DB2PRUNE_ACTION_HISTORY        1         /* Remove history file       */
                                                 /* entries                   */
#define DB2PRUNE_ACTION_LOG            2         /* Remove log files from     */
                                                 /* active log path           */

/* Values for db2Prune - iOptions                                             */
#define DB2PRUNE_OPTION_NONE           0x0       /* Force removal of last     */
                                                 /* backup                    */
#define DB2PRUNE_OPTION_FORCE          0x1       /* Force removal of last     */
                                                 /* backup                    */
#define DB2PRUNE_OPTION_LSNSTRING      0x2       /* piString is an LSN        */
                                                 /* string, used by DB2PRUNE  */
                                                 /* ACTION_LOG                */

/* Prune API input struct                                                     */
typedef SQL_STRUCTURE db2PruneStruct
{
   char            *piString;          /* Timestamp, or lastLSN               */
   db2HistoryEID   iEID;               /* Prune history since this EID        */
   db2Uint32       iAction;            /* What to prune                       */
   db2Uint32       iOptions;           /* Options relevent to particular      */
                                       /* iAction                             */
} db2PruneStruct;

SQL_API_RC SQL_API_FN                  /* Prune history / log                 */
  db2Prune (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* Input parameters                    */
       struct sqlca * pSqlca);         /* SQLCA                               */

/* Generic Prune API input struct                                             */
typedef SQL_STRUCTURE db2gPruneStruct
{
   db2Uint32       iStringLen;         /* length in bytes of piString         */
   char            *piString;          /* Timestamp, or lastLSN               */
   db2HistoryEID   iEID;               /* Prune history since this EID        */
   db2Uint32       iAction;            /* What to prune                       */
   db2Uint32       iOptions;           /* Options relevent to particular      */
                                       /* iAction                             */
} db2gPruneStruct;

SQL_API_RC SQL_API_FN                  /* Generic Prune history / log         */
  db2gPrune (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* Input parameters                    */
       struct sqlca * pSqlca);         /* SQLCA                               */

/******************************************************************************
** Archive Active Log Definitions
*******************************************************************************/

/* Values for db2ArchiveLog - iAllNodeFlag                                    */
#define DB2ARCHIVELOG_NODE_LIST        0         /* Apply to nodes specified  */
                                                 /* in piNodeList             */
#define DB2ARCHIVELOG_ALL_NODES        1         /* Apply to all nodes        */
#define DB2ARCHIVELOG_ALL_EXCEPT       2         /* Apply to all nodes        */
                                                 /* except those in           */
                                                 /* piNodeList                */

/* Archive Active Log API Input Structure                                     */
typedef SQL_STRUCTURE db2ArchiveLogStruct
{
   char            *piDatabaseAlias;   /* Alias of database to archive log    */
                                       /* for                                 */
   char            *piUserName;        /* User name to execute command under  */
   char            *piPassword;        /* Password for username               */
   db2Uint16       iAllNodeFlag;       /* Flag indicating how the iNodeList   */
                                       /* should be used                      */
   db2Uint16       iNumNodes;          /* Number of nodes in piNodeList       */
                                       /* array                               */
   SQL_PDB_NODE_TYPE *piNodeList;      /* Node list                           */
   db2Uint32       iOptions;           /* Future use                          */
} db2ArchiveLogStruct;

SQL_API_RC SQL_API_FN                  /* Archive Active Log                  */
  db2ArchiveLog (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pDB2ArchiveLogStruct,    /* Input parameters                    */
       struct sqlca * pSqlca);         /* SQLCA                               */

/* Generic Archive Active Log API Input Struct                                */
typedef SQL_STRUCTURE db2gArchiveLogStruct
{
   db2Uint32       iAliasLen;          /* Length of database alias field      */
   db2Uint32       iUserNameLen;       /* Length of username field            */
   db2Uint32       iPasswordLen;       /* Length of password field            */
   char            *piDatabaseAlias;   /* Alias of database to archive log    */
                                       /* for                                 */
   char            *piUserName;        /* User name to execute command under  */
   char            *piPassword;        /* Password for username               */
   db2Uint16       iAllNodeFlag;       /* Flag indicating how the iNodeList   */
                                       /* should be used                      */
   db2Uint16       iNumNodes;          /* Number of nodes in piNodeList       */
                                       /* array                               */
   SQL_PDB_NODE_TYPE *piNodeList;      /* Node list                           */
   db2Uint32       iOptions;           /* Future use                          */
} db2gArchiveLogStruct;

SQL_API_RC SQL_API_FN                  /* Generic Archive Active Log          */
  db2gArchiveLog (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pDB2ArchiveLogStruct,    /* Input parameters                    */
       struct sqlca * pSqlca);         /* SQLCA                               */

/* Ping Database Parameter Structure                                          */
typedef SQL_STRUCTURE db2DatabasePingStruct
{
   char            iDbAlias[SQL_ALIAS_SZ + 1]; /* Input: Database alias -     */
                                       /* reserved                            */
   db2Uint16       iNumIterations;     /* Input: Number of iterations         */
   db2Uint32       *poElapsedTime;     /* Output: Array of elapsed times      */
                                       /* (microsec), contains                */
                                       /* iNumIterations elements             */
} db2DatabasePingStruct;

SQL_API_RC SQL_API_FN                  /* Ping Database                       */
  db2DatabasePing (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* In/out parameters                   */
       struct sqlca * pSqlca);         /* SQLCA                               */

/* Generic Ping Database Parameter Structure                                  */
typedef SQL_STRUCTURE db2gDatabasePingStruct
{
   db2Uint16       iDbAliasLength;     /* Input: Db alias name length -       */
                                       /* reserved                            */
   char            iDbAlias[8];        /* Input: Database alias - reserved    */
   db2Uint16       iNumIterations;     /* Input: Number of iterations         */
   db2Uint32       *poElapsedTime;     /* Output: Array of elapsed times      */
                                       /* (microsec), contains                */
                                       /* iNumIterations elements             */
} db2gDatabasePingStruct;

SQL_API_RC SQL_API_FN                  /* Generic Ping Database               */
  db2gDatabasePing (
       db2Uint32 versionNumber,        /* Database version number             */
       void * pParmStruct,             /* In/out parameters                   */
       struct sqlca * pSqlca);         /* SQLCA                               */

/* Convert LSN from internal representation to ascii hex string.              */
/*      _inLsn  - char * that points to the LSN in db2 internal b-byte        */
/*                binary format.                                              */
/*      _outStr - char * to store the output in hex string format.  It        */
/*                should be big enough to store at least 13 bytes.            */

#define db2LsnToString(_inLsn, _outStr) \
         sprintf(_outStr, \
                 "%2.2X%2.2X%2.2X%2.2X%2.2X%2.2X", \
                 (_inLsn).lsnChar[0], (_inLsn).lsnChar[1], \
                 (_inLsn).lsnChar[2], (_inLsn).lsnChar[3], \
                 (_inLsn).lsnChar[4], (_inLsn).lsnChar[5])

/* Convert Monitor Data Interface Structure                                   */
typedef SQL_STRUCTURE db2ConvMonStreamData
{
   void            *poTarget;          /* Pointer to target structure         */
   struct sqlm_header_info *piSource;  /* Pointer to V6 stream                */
   db2Uint32       iTargetType;        /* Target structure type               */
   db2Uint32       iTargetSize;        /* Space allocated for target          */
   db2Uint32       iSourceType;        /* Type of source stream               */
} db2ConvMonStreamData;

SQL_API_RC SQL_API_FN                  /* Convert monitor stream              */
  db2ConvMonStream (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

SQL_API_RC SQL_API_FN                  /* Convert monitor stream              */
  db2gConvMonStream (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Get Snapshot Data Interface Structure                                      */
typedef SQL_STRUCTURE db2GetSnapshotData
{
   struct sqlma    *piSqlmaData;       /* Pointer to monitor area             */
   struct sqlm_collected *poCollectedData; /* Pointer to collected data       */
   void            *poBuffer;          /* Pointer to output buffer            */
   db2Uint32       iVersion;           /* Snapshot version                    */
   db2Uint32       iBufferSize;        /* Size of output buffer               */
   db2Uint32       iStoreResult;       /* Write to file flag                  */
   db2int32        iNodeNumber;        /* Target node                         */
   db2Uint32       *poOutputFormat;    /* Pointer to output format indicator  */
} db2GetSnapshotData;

typedef SQL_STRUCTURE db2gGetSnapshotData
{
   struct sqlma    *piSqlmaData;       /* Pointer to monitor area             */
   struct sqlm_collected *poCollectedData; /* Pointer to collected data       */
   void            *poBuffer;          /* Pointer to output buffer            */
   db2Uint32       iVersion;           /* Snapshot version                    */
   db2Uint32       iBufferSize;        /* Size of output buffer               */
   db2Uint32       iStoreResult;       /* Write to file flag                  */
   db2int32        iNodeNumber;        /* Target node                         */
   db2Uint32       *poOutputFormat;    /* Pointer to output format indicator  */
} db2gGetSnapshotData;

SQL_API_RC SQL_API_FN                  /* Get snapshot                        */
  db2GetSnapshot (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

SQL_API_RC SQL_API_FN                  /* Get snapshot                        */
  db2gGetSnapshot (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Get Snapshot Size Data Interface Structure                                 */
typedef SQL_STRUCTURE db2GetSnapshotSizeData
{
   struct sqlma    *piSqlmaData;       /* Pointer to monitor area             */
   sqluint32       *poBufferSize;      /* Pointer to output buffer            */
   db2Uint32       iVersion;           /* Snapshot version                    */
   db2int32        iNodeNumber;        /* Target node                         */
} db2GetSnapshotSizeData;

typedef SQL_STRUCTURE db2gGetSnapshotSizeData
{
   struct sqlma    *piSqlmaData;       /* Pointer to monitor area             */
   sqluint32       *poBufferSize;      /* Pointer to output buffer            */
   db2Uint32       iVersion;           /* Snapshot version                    */
   db2int32        iNodeNumber;        /* Target node                         */
} db2gGetSnapshotSizeData;

SQL_API_RC SQL_API_FN                  /* Get snapshot size                   */
  db2GetSnapshotSize (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

SQL_API_RC SQL_API_FN                  /* Get snapshot size                   */
  db2gGetSnapshotSize (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Monitor Switches Data Interface Structure                                  */
typedef SQL_STRUCTURE db2MonitorSwitchesData
{
   struct sqlm_recording_group *piGroupStates; /* Pointer to group states     */
   void            *poBuffer;          /* Pointer to output buffer            */
   db2Uint32       iBufferSize;        /* Size of output buffer               */
   db2Uint32       iReturnData;        /* Return data flag                    */
   db2Uint32       iVersion;           /* Snapshot version                    */
   db2int32        iNodeNumber;        /* Target node                         */
   db2Uint32       *poOutputFormat;    /* Pointer to output format indicator  */
} db2MonitorSwitchesData;

typedef SQL_STRUCTURE db2gMonitorSwitchesData
{
   struct sqlm_recording_group *piGroupStates; /* Pointer to group states     */
   void            *poBuffer;          /* Pointer to output buffer            */
   db2Uint32       iBufferSize;        /* Size of output buffer               */
   db2Uint32       iReturnData;        /* Return data flag                    */
   db2Uint32       iVersion;           /* Snapshot version                    */
   db2int32        iNodeNumber;        /* Target node                         */
   db2Uint32       *poOutputFormat;    /* Pointer to output format indicator  */
} db2gMonitorSwitchesData;

SQL_API_RC SQL_API_FN                  /* Get snapshot size                   */
  db2MonitorSwitches (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

SQL_API_RC SQL_API_FN                  /* Get snapshot size                   */
  db2gMonitorSwitches (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Monitor Reset Data Interface Structure                                     */
typedef SQL_STRUCTURE db2ResetMonitorData
{
   db2Uint32       iResetAll;          /* Reset value flag                    */
   char            *piDbAlias;         /* Database alias                      */
   db2Uint32       iVersion;           /* Snapshot version                    */
   db2int32        iNodeNumber;        /* Target node                         */
} db2ResetMonitorData;

/* Monitor Reset Data General Interface Structure                             */
typedef SQL_STRUCTURE db2gResetMonitorData
{
   db2Uint32       iResetAll;          /* Reset value flag                    */
   char            *piDbAlias;         /* Database alias                      */
   db2Uint32       iDbAliasLength;     /* Length of DB alias                  */
   db2Uint32       iVersion;           /* Snapshot version                    */
   db2int32        iNodeNumber;        /* Target node                         */
} db2gResetMonitorData;

SQL_API_RC SQL_API_FN                  /* Get snapshot size                   */
  db2ResetMonitor (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

SQL_API_RC SQL_API_FN                  /* Get snapshot size                   */
  db2gResetMonitor (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Restart Database Structure                                                 */
typedef struct db2RestartDbStruct
{
   char            *piDatabaseName;    /* Database name or alias              */
   char            *piUserId;          /* User Id                             */
   char            *piPassword;        /* Password                            */
   char            *piTablespaceNames; /* Droppending tablespace name list    */
   db2int32        iOption;            /* Suspend or resume                   */
} db2RestartDbStruct;

SQL_API_RC SQL_API_FN                  /* Database Restart                    */
  db2DatabaseRestart (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

typedef struct db2gRestartDbStruct
{
   db2Uint32       iDatabaseNameLen;   /* Length in bytes of piDatabaseName   */
   db2Uint32       iUserIdLen;         /* Length in bytes of piUserId         */
   db2Uint32       iPasswordLen;       /* Length in bytes of piPassword       */
   db2Uint32       iTablespaceNamesLen; /* Length in bytes of                 */
                                       /* piTablespaceNames                   */
   char            *piDatabaseName;    /* Database name or alias              */
   char            *piUserId;          /* User Id                             */
   char            *piPassword;        /* Password                            */
   char            *piTablespaceNames; /* Tablespace name list                */
} db2gRestartDbStruct;

SQL_API_RC SQL_API_FN                  /* Generic Database Restart            */
  db2gDatabaseRestart (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */

/* Suspend I/O Database Structure                                             */
typedef struct db2SetWriteDbStruct
{
   db2int32        iOption;            /* Suspend or resume                   */
   char            *piTablespaceNames; /* Suspending tablespace name list:    */
                                       /* empty for all Tablespaces           */
} db2SetWriteDbStruct;

SQL_API_RC SQL_API_FN                  /* Set Write Suspend/Resume For DB     */
  db2SetWriteForDB (
   db2Uint32 versionNumber,            /* Database version number             */
   void * pParmStruct,                 /* In/out parameters                   */
   struct sqlca * pSqlca);             /* SQLCA                               */


#ifdef __cplusplus 
}
#endif

#endif /* SQL_H_DB2APIDF */
