/******************************************************************************
 
 Source File Name: db2AuCfg
 
 (C) COPYRIGHT International Business Machines Corp. 1987, 1999
 All Rights Reserved
 Licensed Materials - Property of IBM
 
 US Government Users Restricted Rights - Use, duplication or
 disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 
 Function = Include File defining:
              db2AutoConfig and corresponding data structures

*****************************************************************************/

 
#ifndef SQL_H_DB2AUCFG
#define SQL_H_DB2AUCFG

#include "sqlenv.h"
#include "db2ApiDf.h"

/* type definitions for the smartguide */
typedef struct {
  db2int32  token;
  db2int32  value;
} db2AutoConfigElement;
      
typedef struct {
  db2Uint32  numElements;            /* number of  array elements*/
  db2AutoConfigElement *  pElements; /* the element array */
} db2AutoConfigArray;

typedef db2AutoConfigArray  db2AutoConfigInput;
typedef db2AutoConfigArray  db2AutoConfigDiags;

typedef struct {
  db2Uint32  numElements;
  struct sqlfupd *  pConfigs;
  void * pDataArea;
} db2ConfigValues;

typedef struct { 
  db2ConfigValues  oOldDbValues;   /* current/old database configurations */
  db2ConfigValues  oOldDbmValues;  /* current/old database manager configurations */
  db2ConfigValues  oNewDbValues; /* suggested/new database configurations */
  db2ConfigValues  oNewDbmValues;  /* suggested/new database manager configurations */
  db2AutoConfigDiags  oDiagnostics; /* diagnostic details */
} db2AutoConfigOutput;

#define DB2_SG_PROD_VERSION_SIZE  16

typedef struct {
  db2int32  iProductID;                             /* product id */
  char iProductVersion[DB2_SG_PROD_VERSION_SIZE+1]; /* product version */
  char iDbAlias[SQL_ALIAS_SZ+1];                    /* database alias */
  db2int32  iApply;                /* update the configuration automatically */
  db2AutoConfigInput  iParams;     /* input parameters to the smart guide */
  db2AutoConfigOutput  oResult;      /* results from the smart guide */
} db2AutoConfigInterface;

/* Tokens for the SmartGuide input parameters */
#define DB2_SG_MEMORY_PERCENTAGE   1  /* The percentage of the memory the
                                         database manager trys to use */
#define DB2_SG_WORKLOAD         2  /* The type of workload that best
                                         reflects the database. */
#define DB2_SG_NUM_STATEMENT      3  /* The average number of SQL statements
                                         in a single unit of work.  */
#define DB2_SG_TRANS_PER_MINUTE      4  /* The number of transactions per
                                         minute. */
#define DB2_SG_ADMIN_PRIORITY      5  /* The database administration
                                         priority */
#define DB2_SG_IS_POPULATED      6  /* Is the database populated with
                                         data */
#define DB2_SG_LOCAL_APPLICATION   7  /* Average number of connected local
                                         application */
#define DB2_SG_REMOTE_APPLICATION  8  /* Average number of connected remote
                                         application */
#define DB2_SG_ISOLATION_LEVEL      9  /* Isolation level that best reflects
                                         your applications */

/* Valid values for the SmartGuide input parameters */


#define DB2_SG_MEMORY_PERCENTAGE_MIN 1 
#define DB2_SG_MEMORY_PERCENTAGE_MAX 100 


#define DB2_SG_WORKLOAD_MIN             1
#define DB2_SG_WORKLOAD_QUERIES      1
#define DB2_SG_WORKLOAD_MIXED      2
#define DB2_SG_WORKLOAD_TRANSACTIONS   3
#define DB2_SG_WORKLOAD_MAX             3

#define DB2_SG_ADMIN_PRIORITY_MIN               1
#define DB2_SG_ADMIN_PRIORITY_TRANSACTION       1
#define DB2_SG_ADMIN_PRIORITY_BOTH      2
#define DB2_SG_ADMIN_PRIORITY_RECOVERY      3
#define DB2_SG_ADMIN_PRIORITY_MAX      3


#define DB2_SG_TRANS_PER_MINUTE_MIN 1     
#define DB2_SG_TRANS_PER_MINUTE_MAX 50000 


#define DB2_SG_IS_POPULATED_MIN           1
#define DB2_SG_IS_POPULATED_YES           1
#define DB2_SG_IS_POPULATED_NO          2
#define DB2_SG_IS_POPULATED_MAX           2


#define DB2_SG_LOCAL_APPLICATION_MIN 0   
#define DB2_SG_LOCAL_APPLICATION_MAX 5000


#define DB2_SG_REMOTE_APPLICATION_MIN 0   
#define DB2_SG_REMOTE_APPLICATION_MAX 5000


#define DB2_SG_ISOLATION_LEVEL_MIN              1
#define DB2_SG_ISOLATION_LEVEL_REPEAT_READ   1
#define DB2_SG_ISOLATION_LEVEL_READ_STABILITY   2
#define DB2_SG_ISOLATION_LEVEL_CURSOR_STABILITY   3
#define DB2_SG_ISOLATION_LEVEL_UNCOMMITTED_READ   4
#define DB2_SG_ISOLATION_LEVEL_MAX         4



/* Tokens for SmartGuide diagnostics :
** These token/values pairs may appear in db2AutoConfigOutput.db2AutoConfigDiags.
** Some of tokens return a meaningful value, and some are just flags indicating 
** a state (for which the value will usually be -1, but should be ignored in
** any event).
** DB2_SG_DIAG_NO_VALUE  - the "no value" value for flag type diagnostic tokens
** DB2_SG_DIAG_DEFAULT_USED  - flag indicating the default SmartGuide is returning this result set
** DB2_SG_DIAG_NOT_ENOUGH_MEMORY - value returned is the recommended amount of memory for given inputs
** DB2_SG_DIAG_NOT_ENOUGH_DISKS  - value returned is the recommended # of disks for given inputs
** DB2_SG_DIAG_LOW_MEMORY_PERCENTAGE  - value returned is the %age of memory to expect DB2 to consume for fiven inputs 
** DB2_SG_DIAG_DBA_MEMORY  - value returned is the actual amount of physical memory on the target machine ,
**                           and accompanies other memory diagnostics
** DB2_SG_DIAG_DBA_BUFFER_POOL_SIZE  - flag indicating that the bufferpools could not be increased due to memory constraints
** DB2_SG_DIAG_DBA_TRANSACTION_RATE  - flag indicating that the requested transaction rate is optimistic
*/

#define DB2_SG_DIAG_NO_VALUE                    -1
#define DB2_SG_DIAG_DEFAULT_USED                 0
#define DB2_SG_DIAG_NOT_ENOUGH_MEMORY           -1  
#define DB2_SG_DIAG_NOT_ENOUGH_DISKS            -2  
#define DB2_SG_DIAG_LOW_MEMORY_PERCENTAGE       -3
#define DB2_SG_DIAG_DBA_MEMORY                  1100   /* See associated DBA1100 message */
#define DB2_SG_DIAG_DBA_BUFFER_POOL_SIZE        1108   /* See associated DBA1108 message */
#define DB2_SG_DIAG_DBA_TRANSACTION_RATE        1109   /* See associated DBA1109 message */



/* Product ID for the product using the Smart Guide */
#define DB2_SG_PID_DEFAULT           0
#define DB2_SG_PID_WEBSPHERE_COMMERCE_SUITE 	1
#define DB2_SG_PID_SAP              2
#define DB2_SG_PID_WEBSPHERE_ADVANCED_SERVER	3 
#define DB2_SG_PID_SIEBEL	4 


/* Indicate to apply the smartguide recommendation or not */
#define DB2_SG_NOT_APPLY         0
#define DB2_SG_APPLY         1


/* Smartguide return codes */
#define DB2_SG_RC_OK         0
#define DB2_SG_RC_FAIL         -1

#ifdef __cplusplus
extern "C" {
#endif
  
SQL_API_RC SQL_API_FN
db2AutoConfig(
  db2Uint32 db2VersionNumber,       /* versions defined in db2ApiDf.h */
  void * pAutoConfigInterface,   /* pointer to db2AutoConfigInterface */
  struct sqlca * pSqlca);

SQL_API_RC SQL_API_FN
db2AutoConfigFreeMemory(
  db2Uint32  db2VersionNumber,                
  void * pAutoConfigInterface,
  struct sqlca * pSqlca);
  
#ifdef __cplusplus
}
#endif

#endif  /* DB2AUCFG_H */
