/*******************************************************************************
**
** Source File Name = dbinst.c 
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995, 2000 
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**    PURPOSE :
**       an example showing how to use DATABASE INSTANCE APIs in order to:
**          - Attach to an instance
**          - Retrieve the instance
**          - Change the password
**          - Reset the password
**          - Detach from the instance.
**
**    APIs USED :
**       ATTACH TO INSTANCE               sqleatin
**       GET INSTANCE                     sqlegins
**       ATTACH AND CHANGE PASSWORD       sqleatcp
**       DETACH FROM INSTANCE             sqledtin
**
**    STRUCTURES USED :
**       sqlca
**
**    OTHER FUNCTIONS DECLARED :
**       'C' COMPILER LIBRARY :
**          stdio.h  -  printf
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.C]          related information available.
**                               This procedure is located in the UTIL.C file.
**
**    EXTERNAL DEPENDENCIES :
**       - Compile and link with the IBM Cset++ compiler (AIX and OS/2)
**         or the Microsoft Visual C++ compiler (Windows) 
**         or the compiler supported on your platform.
**
** For more information about these samples see the README file.
**
** For more information on programming in C, see the:
**   -  "Programming in C and C++" section of the Application Development Guide
** For more information on building C applications, see the:
**   -  "Building C Applications" section of the Application Building Guide.
**
** For more information on the SQL language see the SQL Reference.
**
*******************************************************************************/

#include <string.h>
#include <stdio.h>
#include <sqlenv.h>
#include "utilapi.h"

int main(int argc, char *argv[])
{
  struct sqlca sqlca;
  char input;
  char instName[SQL_INSTNAME_SZ + 1];
  char newPassword[]="NewPassword";

  /*********************************************
    the first argument is the instance name
    the second argument is the user name
    the third argument is the password
  *********************************************/
  if (argc != 4)
  {
    printf("\n\nUSAGE: dbinst instance_name user_name password\n\n");
    return 1;
  }

  printf("sample program : dbinst.c\n");

  /*******************************\
  * ATTACH TO INSTANCE API called *
  \*******************************/
  sqleatin(argv[1], argv[2], argv[3], &sqlca);
  API_SQL_CHECK("attach to instance");

  printf("\nATTACH TO INSTANCE API called\n");
  printf("for instance :%s\n", argv[1]);

  /*************************\
  * GET INSTANCE API called *
  \*************************/
  instName[SQL_INSTNAME_SZ] = '\0';

  sqlegins(instName, &sqlca);
  API_SQL_CHECK("get instance name");

  printf("\nGET INSTANCE API called\n");

  printf("current instance = %s\n", instName);
  printf("\nATTACH AND CHANGE PASSWORD API\n");
  printf("Warning: This API will attempt to change the instance\n");
  printf("password, and then change back to the original password.\n");
  printf("Some systems do not allow a change back to a recent old\n");
  printf("password and/or require certain restrictions on password\n");
  printf("format that may not be reflected in the new password\n");
  printf("provided. You can alter the source code to comply with\n");    
  printf("these restrictions, if they apply to your system.\n");    
  printf("\nWould you like to run this API?(y/n)\n");

  input = getchar();
  if (input != 'y')
  {
    return 0;
  }
  else
  {
    printf("\nCalling ATTACH AND CHANGE PASSWORD API...\n");

    /***************************************\
    * ATTACH AND CHANGE PASSWORD API called *
    \***************************************/
    sqleatcp(argv[1], argv[2], argv[3], newPassword, &sqlca);
    API_SQL_CHECK("change password");

    printf("\nATTACH AND CHANGE PASSWORD API called\n");
    printf("the old password is :%s\n", argv[3]);
    printf("the new password is :%s\n", newPassword);

    printf("\nCalling ATTACH AND CHANGE PASSWORD API...\n");

    /***************************************\
    * ATTACH AND CHANGE PASSWORD API called *
    \***************************************/
    sqleatcp(argv[1], argv[2], newPassword, argv[3], &sqlca);
    API_SQL_CHECK("reset password");

    printf("\nATTACH AND CHANGE PASSWORD API called\n");
    printf("the password is reset to :%s\n", argv[3]);

    /*********************************\
    * DETACH FROM INSTANCE API called *
    \*********************************/
    sqledtin(&sqlca);
    API_SQL_CHECK("detach from instance");

    printf("\nDETACH FROM INSTANCE API called\n", instName);

    return 0;
  }
}
/* end of program : dbinst.c */

