/******************************************************************************
**                                                                        
** Source File Name = pipes.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995, 1999
** All Rights Reserved.
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
** Example of reading from a pipe destination on UNIX.
** To exercise named pipe use the following in pipe description field:
**   /home/iwm/bin/pipe /home/iwm/bin/args.out /home/iwm/bin/data.out $(PIPE)
** To exercise standard input pipe use the following in pipe description field:
**   /home/iwm/bin/pipe /home/iwm/bin/args.out /home/iwm/bin/data.out
**
** For more information about these samples see the README file.
**
******************************************************************************/

#include <stdio.h>
#include <errno.h>

main(int argc, char ** argv)
{
   char ch;
   int i;
   FILE *fpArgsOut;
   FILE *fpDataOut;
   FILE *fpPipeIn;
 
   fpArgsOut = fopen ( argv[1], "a");
   fprintf ( fpArgsOut,"\n\n++++++++++++++++++++++\n");
   for ( i = 0; i < argc; i++ )
      fprintf ( fpArgsOut, " %d : %s \n", i,argv[i]);
   fflush ( fpArgsOut ) ;
   fclose( fpArgsOut );
 
   fpDataOut = fopen ( argv[2], "w" );
   if ( !fpDataOut )
   {
      fprintf ( fpArgsOut, "Error opening %s : %d ", argv[2], errno);
      fflush ( fpArgsOut ) ;
   }
 
   /* if reading from STDIN */
   if (argc == 3) {
      for (;;) {
         if (fscanf( stdin, "%c", &ch) == EOF)
            break;
         fprintf( fpDataOut, "%c", ch);
      }
   }
   /* else if reading from NAMED PIPE */
   else if (argc == 4) {
      fpPipeIn = fopen ( argv[3], "r" ); 
      for (;;) {
         if (fscanf( fpPipeIn, "%c", &ch) == EOF)
            break;
         fprintf( fpDataOut, "%c", ch);
      }
      fflush( fpPipeIn );
      fclose( fpPipeIn );
   }
   
 
   fflush( fpDataOut );
   fclose( fpDataOut ); 
}
