/*******************************************************************************
**                                                                        
** Source File Name = apinfo.c                                       
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995, 2000
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**    Shows how to get/set info at application level.
**                                                                        
** For more information about these samples see the README file.
**
** For more information on programming in CLI see the:
**     - "Building CLI Applications" section of the Application Building Guide, and the
**     - CLI Guide and Reference.
**
** For more information on the SQL language see the SQL Reference.
**
*******************************************************************************/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <sqlcli1.h>
#include "utilcli.h"          /* Header file for CLI sample code */

int EnvAttrSetGet( SQLHANDLE) ;
int SuppFunctionsList( SQLHANDLE, char *, char *, char *) ;

/*******************************************************************
** main
*******************************************************************/
int main( int argc, char * argv[] )
{   SQLRETURN   sqlrc = SQL_SUCCESS;
    int         rc = 0; 
    SQLHANDLE   henv;  /* environment handle */
    
    char       dbAlias[SQL_MAX_DSN_LENGTH + 1] ;
    char       user[MAX_UID_LENGTH + 1] ;
    char       pswd[MAX_PWD_LENGTH + 1] ;

    /* checks the command line arguments */
    rc = CmdLineArgsCheck1( argc, argv, dbAlias, user, pswd );
    if ( rc != 0 ) return( rc ) ;

    printf("\n\nCLI APP.: HOW TO GET/SET INFO AT CLI APP. LEVEL.\n");


    /* allocate an environment handle */
    sqlrc = SQLAllocHandle( SQL_HANDLE_ENV, SQL_NULL_HANDLE, &henv ) ;
    if ( sqlrc != SQL_SUCCESS ) 
    {   printf( "\n--ERROR while allocating the environment handle.\n" ) ;
        printf( "  sqlrc             = %d\n", sqlrc);
        printf( "  line              = %d\n", __LINE__);
        printf( "  file              = %s\n", __FILE__);	    
        return( 1 ) ;
    }


    rc = EnvAttrSetGet( henv) ;    
    rc = SuppFunctionsList( henv, dbAlias, user, pswd) ;    

    /* free the environment handle */ 
    sqlrc = SQLFreeHandle( SQL_HANDLE_ENV,  henv ) ;
    ENV_HANDLE_CHECK( henv, sqlrc ) ;

    return( 0 ) ;
}                                  /* end main */
 
/******************************************************************************
**    EnvAttrSetGet
******************************************************************************/
int EnvAttrSetGet( SQLHANDLE henv )
{   SQLRETURN  sqlrc = SQL_SUCCESS;
    int        rc = 0;

    SQLINTEGER output_nts;    

    printf("\nUSE THE CLI FUNCTIONS\n");
    printf("-SQLSetEnvAttr\n-SQLGetEnvAttr\n");
    printf("TO SET/GET ENVIRONMENT ATTRIBUTES:\n");    

 
    printf( "\n    Set the env. attr. SQL_ATTR_OUTPUT_NTS to TRUE.\n" ) ;
    sqlrc = SQLSetEnvAttr( henv,
                           SQL_ATTR_OUTPUT_NTS,
                           ( SQLPOINTER ) SQL_TRUE,
                           0 ) ;
    ENV_HANDLE_CHECK( henv, sqlrc) ;    

    printf( "    Get the env. attr. SQL_ATTR_OUTPUT_NTS.\n" ) ;
    /*-->00000611.snippet */
    sqlrc = SQLGetEnvAttr( henv, SQL_ATTR_OUTPUT_NTS, &output_nts, 0, NULL ) ;
    ENV_HANDLE_CHECK( henv, sqlrc) ;    
    /* 00000611.snippet <--*/
    printf( "        Null Termination of Output strings is: " ) ;
    if ( output_nts == SQL_TRUE ) printf( "True\n" ) ;
    else printf( "False\n" ) ;

    

    return( 0 ) ;
}

typedef struct {
  SQLUSMALLINT id ;
  char * name ;
} functionInfo ;

functionInfo functions[] = {
  { SQL_API_SQLALLOCCONNECT,     "SQLALLOCCONNECT"     },
  { SQL_API_SQLALLOCENV,         "SQLALLOCENV"         },
  { SQL_API_SQLALLOCHANDLE,      "SQLALLOCHANDLE"      },
  { SQL_API_SQLALLOCSTMT,        "SQLALLOCSTMT"        },
  { SQL_API_SQLBINDCOL,          "SQLBINDCOL"          },
  { SQL_API_SQLBINDFILETOCOL,    "SQLBINDFILETOCOL"    },
  { SQL_API_SQLBINDFILETOPARAM,  "SQLBINDFILETOPARAM"  },
  { SQL_API_SQLBINDPARAM,        "SQLBINDPARAM"        },
  { SQL_API_SQLBINDPARAMETER,    "SQLBINDPARAMETER"    },
  { SQL_API_SQLBROWSECONNECT,    "SQLBROWSECONNECT"    },
  { SQL_API_SQLCANCEL,           "SQLCANCEL"           },
  { SQL_API_SQLCLOSECURSOR,      "SQLCLOSECURSOR"      },
  { SQL_API_SQLCOLATTRIBUTE,     "SQLCOLATTRIBUTE"     },
  { SQL_API_SQLCOLATTRIBUTES,    "SQLCOLATTRIBUTES"    },
  { SQL_API_SQLCOLUMNPRIVILEGES, "SQLCOLUMNPRIVILEGES" },
  { SQL_API_SQLCOLUMNS,          "SQLCOLUMNS"          },
  { SQL_API_SQLCONNECT,          "SQLCONNECT"          },
  { SQL_API_SQLCOPYDESC,         "SQLCOPYDESC"         },
  { SQL_API_SQLDATASOURCES,      "SQLDATASOURCES"      },
  { SQL_API_SQLDESCRIBECOL,      "SQLDESCRIBECOL"      },
  { SQL_API_SQLDESCRIBEPARAM,    "SQLDESCRIBEPARAM"    },
  { SQL_API_SQLDISCONNECT,       "SQLDISCONNECT"       },
  { SQL_API_SQLDRIVERCONNECT,    "SQLDRIVERCONNECT"    },
  { SQL_API_SQLENDTRAN,          "SQLENDTRAN"          },
  { SQL_API_SQLERROR,            "SQLERROR"            },
  { SQL_API_SQLEXECDIRECT,       "SQLEXECDIRECT"       },
  { SQL_API_SQLEXECUTE,          "SQLEXECUTE"          },
  { SQL_API_SQLEXTENDEDFETCH,    "SQLEXTENDEDFETCH"    },
  { SQL_API_SQLFETCH,            "SQLFETCH"            },
  { SQL_API_SQLFETCHSCROLL,      "SQLFETCHSCROLL"      },
  { SQL_API_SQLFOREIGNKEYS,      "SQLFOREIGNKEYS"      },
  { SQL_API_SQLFREECONNECT,      "SQLFREECONNECT"      },
  { SQL_API_SQLFREEENV,          "SQLFREEENV"          },
  { SQL_API_SQLFREEHANDLE,       "SQLFREEHANDLE"       },
  { SQL_API_SQLFREESTMT,         "SQLFREESTMT"         },
  { SQL_API_SQLGETCONNECTATTR,   "SQLGETCONNECTATTR"   },
  { SQL_API_SQLGETCONNECTOPTION, "SQLGETCONNECTOPTION" },
  { SQL_API_SQLGETCURSORNAME,    "SQLGETCURSORNAME"    },
  { SQL_API_SQLGETDATA,          "SQLGETDATA"          },
  { SQL_API_SQLGETDESCFIELD,     "SQLGETDESCFIELD"     },
  { SQL_API_SQLGETDESCREC,       "SQLGETDESCREC"       },
  { SQL_API_SQLGETDIAGFIELD,     "SQLGETDIAGFIELD"     },
  { SQL_API_SQLGETDIAGREC,       "SQLGETDIAGREC"       },
  { SQL_API_SQLGETENVATTR,       "SQLGETENVATTR"       },
  { SQL_API_SQLGETFUNCTIONS,     "SQLGETFUNCTIONS"     },
  { SQL_API_SQLGETINFO,          "SQLGETINFO"          },
  { SQL_API_SQLGETLENGTH,        "SQLGETLENGTH"        },
  { SQL_API_SQLGETPOSITION,      "SQLGETPOSITION"      },
  { SQL_API_SQLGETSQLCA,         "SQLGETSQLCA"         },
  { SQL_API_SQLGETSTMTATTR,      "SQLGETSTMTATTR"      },
  { SQL_API_SQLGETSTMTOPTION,    "SQLGETSTMTOPTION"    },
  { SQL_API_SQLGETSUBSTRING,     "SQLGETSUBSTRING"     },
  { SQL_API_SQLGETTYPEINFO,      "SQLGETTYPEINFO"      },
  { SQL_API_SQLMORERESULTS,      "SQLMORERESULTS"      },
  { SQL_API_SQLNATIVESQL,        "SQLNATIVESQL"        },
  { SQL_API_SQLNUMPARAMS,        "SQLNUMPARAMS"        },
  { SQL_API_SQLNUMRESULTCOLS,    "SQLNUMRESULTCOLS"    },
  { SQL_API_SQLPARAMDATA,        "SQLPARAMDATA"        },
  { SQL_API_SQLPARAMOPTIONS,     "SQLPARAMOPTIONS"     },
  { SQL_API_SQLPREPARE,          "SQLPREPARE"          },
  { SQL_API_SQLPRIMARYKEYS,      "SQLPRIMARYKEYS"      },
  { SQL_API_SQLPROCEDURECOLUMNS, "SQLPROCEDURECOLUMNS" },
  { SQL_API_SQLPROCEDURES,       "SQLPROCEDURES"       },
  { SQL_API_SQLPUTDATA,          "SQLPUTDATA"          },
  { SQL_API_SQLROWCOUNT,         "SQLROWCOUNT"         },
  { SQL_API_SQLSETCOLATTRIBUTES, "SQLSETCOLATTRIBUTES" },
  { SQL_API_SQLSETCONNECTATTR,   "SQLSETCONNECTATTR"   },
  { SQL_API_SQLSETCONNECTION,    "SQLSETCONNECTION"    },
  { SQL_API_SQLSETCONNECTOPTION, "SQLSETCONNECTOPTION" },
  { SQL_API_SQLSETCURSORNAME,    "SQLSETCURSORNAME"    },
  { SQL_API_SQLSETDESCFIELD,     "SQLSETDESCFIELD"     },
  { SQL_API_SQLSETDESCREC,       "SQLSETDESCREC"       },
  { SQL_API_SQLSETENVATTR,       "SQLSETENVATTR"       },
  { SQL_API_SQLSETPARAM,         "SQLSETPARAM"         },
  { SQL_API_SQLSETPOS,           "SQLSETPOS"           },
  { SQL_API_SQLSETSCROLLOPTIONS, "SQLSETSCROLLOPTIONS" },
  { SQL_API_SQLSETSTMTATTR,      "SQLSETSTMTATTR"      },
  { SQL_API_SQLSETSTMTOPTION,    "SQLSETSTMTOPTION"    },
  { SQL_API_SQLSPECIALCOLUMNS,   "SQLSPECIALCOLUMNS"   },
  { SQL_API_SQLSTATISTICS,       "SQLSTATISTICS"       },
  { SQL_API_SQLTABLEPRIVILEGES,  "SQLTABLEPRIVILEGES"  },
  { SQL_API_SQLTABLES,           "SQLTABLES"           },
  { SQL_API_SQLTRANSACT,         "SQLTRANSACT"         },
  { 0,                           ( char * ) 0          }
} ;


/******************************************************************************
**    SuppFunctionsList 
******************************************************************************/
int SuppFunctionsList( SQLHANDLE henv,
                       char dbAlias[],
                       char user[], 
                       char pswd[] )
{   SQLRETURN  sqlrc = SQL_SUCCESS;
    int        rc = 0;

    SQLHANDLE   hdbc;  /* connection handle */	 

    SQLUSMALLINT supported ;
    int func_pos ;    

    printf("\nUSE THE CLI FUNCTIONS\n");
    printf("-SQLAllocHandle\n-SQLConnect\n");
    printf("-SQLGetFunctions\n");    
    printf("-SQLDisconnect\n-SQLFreeHandle\n");    
    printf("TO LIST THE SUPPORTED CLI FNCTIONS:\n");    

    /* allocate a database connection handle */
    sqlrc = SQLAllocHandle( SQL_HANDLE_DBC, henv, &hdbc ) ;
    HANDLE_CHECK( SQL_HANDLE_ENV, henv, sqlrc, &henv, &hdbc ) ;

    /* connect to the database */
    printf( "\n    Connecting to the database %s ...\n", dbAlias ) ;    
    sqlrc = SQLConnect( hdbc,
                     (SQLCHAR *)dbAlias, SQL_NTS,
                     (SQLCHAR *)user, SQL_NTS,
                     (SQLCHAR *)pswd, SQL_NTS
                   ) ;
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;     
    printf( "    Connected to the database %s.\n", dbAlias ) ;


    printf("    List the supported CLI functions:\n");    
    
    func_pos = 0;
    while ( functions[func_pos].id != 0 )
    {   sqlrc = SQLGetFunctions( hdbc,
                                 functions[func_pos].id,
                                 &supported ) ;
        HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    
	
        if ( supported )
            printf( "        %-20s is supported\n",
                    functions[func_pos].name ) ;
        else
            printf( "        %-20s is not supported\n",
                  functions[func_pos].name ) ;

        func_pos++ ;
    }

    
    /*********   Stop using the connection  **************************/
    
    /* disconnect from the database */   
    printf( "\n    Disconnecting from the database %s ...\n", dbAlias ) ;
    sqlrc = SQLDisconnect( hdbc ) ;
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;
    printf( "    Disconnected from the database %s.\n", dbAlias ) ;    

    /* free the connection handle */    
    sqlrc = SQLFreeHandle( SQL_HANDLE_DBC, hdbc ) ;
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    
 
    return( 0 ) ;
}


