-- This is a CLP script that creates an SQL procedure.
-- To create the SQL procedure using this script, perform the following steps:
-- 1. connect to the database
-- 2. issue the command "db2 -td@ -vf <script-name>"
--    where <script-name> represents the name of this script
--
-- To call this SQL procedure from the command line, perform the following steps:
-- 1. connect to the database
-- 2. issue the following command:
--    db2 "CALL bump_salary (51)"
--
-- The sample "nestcase.sqc" demonstrates how to call this SQL procedure using
-- an embedded C client application.

CREATE PROCEDURE bump_salary (IN deptnumber SMALLINT) 
LANGUAGE SQL 
BEGIN 
   DECLARE SQLSTATE CHAR(5);
   DECLARE v_salary DOUBLE;
   DECLARE v_id SMALLINT;
   DECLARE v_years SMALLINT;
   DECLARE at_end INT DEFAULT 0;
   DECLARE not_found CONDITION FOR SQLSTATE '02000';

   DECLARE C1 CURSOR FOR
     SELECT id, CAST(salary AS DOUBLE), years 
     FROM staff 
     WHERE dept = deptnumber;
   DECLARE CONTINUE HANDLER FOR not_found 
     SET at_end = 1;

   OPEN C1;
   FETCH C1 INTO v_id, v_salary, v_years;
   WHILE at_end = 0 DO
     CASE 
       WHEN (v_salary < 2000 * v_years)
         THEN UPDATE staff 
           SET salary = 2150 * v_years 
           WHERE id = v_id;
       WHEN (v_salary < 5000 * v_years)
         THEN CASE 
           WHEN (v_salary < 3000 * v_years) 
             THEN UPDATE staff 
               SET salary = 3000 * v_years 
               WHERE id = v_id;
           ELSE UPDATE staff 
             SET salary = v_salary * 1.10 
             WHERE id = v_id;
         END CASE;
       ELSE UPDATE staff 
         SET job = 'PREZ' 
         WHERE id = v_id;
     END CASE;
     FETCH C1 INTO v_id, v_salary, v_years;
   END WHILE;
   CLOSE C1;
END @
