/*******************************************************************************
**
** Source File Name = rsultset.c 
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995, 2000
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**    PURPOSE :
**  Client sample for the rsultset.db2 'MEDIAN_RESULT_SET' SQL procedure
**  sample that demonstrates how to return a result set from a stored
**  procedure.
**
** For more information about these samples see the README file.
**
** For more information on SQL procedures refer to the
**   SQL Procedure Guide and Reference.
**
** For more information on programming in CLI refer to the:
**     - "Building CLI Applications" section of the Application Building Guide, and the
**     - CLI Guide and Reference.
**
** For more information on the SQL language refer to the SQL Reference.
**
*******************************************************************************/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <sqlcli1.h>
#include "utilcli.h"          /* Header file for CLI sample code */

int main( int argc, char * argv[] ) {

    SQLHANDLE henv, hdbc, hstmt ;
    SQLRETURN sqlrc = SQL_SUCCESS ;
    int rc = 0 ;

/*--> SQLL1X45.SCRIPT */

    SQLCHAR * stmt = ( SQLCHAR * ) "CALL MEDIAN_RESULT_SET( ? )" ;

/* Declare Local Variables for Holding Returned Data */
     SQLDOUBLE   sal     = 20000.0;  /* Bound to parameter marker in stmt */
     SQLINTEGER  salind  = 0;    /* Indicator variable for sal */
/*<-- */

    char       dbAlias[SQL_MAX_DSN_LENGTH + 1] ;
    char       user[MAX_UID_LENGTH + 1] ;
    char       pswd[MAX_PWD_LENGTH + 1] ;

    /* checks the command line arguments */
    rc = CmdLineArgsCheck1( argc, argv, dbAlias, user, pswd );
    if ( rc != 0 )
    {   return( 1 ) ;
    }  

    /* initialize the CLI application with autocommit off */
    rc = CLIAppInit( dbAlias, user, pswd, &henv, &hdbc,
                     (SQLPOINTER)SQL_AUTOCOMMIT_OFF);
    if ( rc != 0 ) return( rc ) ;

    sqlrc = SQLAllocHandle( SQL_HANDLE_STMT, hdbc, &hstmt ) ;
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    

/*--> */
   /**********************************************************\
   * Call the Remote Procedure via CALL with bound parameters *
   \**********************************************************/
   printf("Use CALL with Host Variable to invoke the Server Procedure "
      "named MEDIAN_RESULT_SET\n");
   salind = 0;                  /* Sal is an INOUT parameter */

   /* Prepare the call statement */
    sqlrc = SQLPrepare(hstmt, stmt, SQL_NTS);
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    

    /* Bind the parameter to application variables (sal and salind) */
    sqlrc = SQLBindParameter(hstmt, 1, SQL_PARAM_OUTPUT, SQL_C_DOUBLE, SQL_DOUBLE,
                      0, 0, &sal, 0, &salind);
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    

    SQLExecute(hstmt);
    /* Ignore Warnings */
    if (sqlrc != SQL_SUCCESS & sqlrc != SQL_SUCCESS_WITH_INFO)
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    

   printf("Server Procedure Complete.\n");

   /* Print Salary Returned in the bound application variables */
   if (salind == SQL_NULL_DATA) /* Check for null value */
      printf("Median Salary = NULL\n");
   else
      printf("Median Salary = %.2f\n\n", sal );
/*<-- */

    printf("Print a result set consisting of employees with greater than median salaries.\n");

    /* Get first result set */
    sqlrc = StmtResultPrint(hstmt);
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    

    /* Check for another result set */
    sqlrc = SQLMoreResults(hstmt);
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    

    if (sqlrc == SQL_SUCCESS) /* There is another result set */
    {
       printf("\nPrint a result set consisting of employees with lesser than median salaries.\n");
       /* Get second result set */
       sqlrc = StmtResultPrint(hstmt);
       HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    
    }

    sqlrc = SQLFreeHandle( SQL_HANDLE_STMT, hstmt ) ;
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    

    /* COMMIT, free resources and exit */

    sqlrc = SQLEndTran( SQL_HANDLE_DBC, hdbc, SQL_COMMIT ) ;
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;    

    printf( "\n>Disconnecting .....\n" ) ;
    sqlrc = SQLDisconnect( hdbc ) ;
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;     

    sqlrc = SQLFreeHandle( SQL_HANDLE_DBC, hdbc ) ;
    HANDLE_CHECK( SQL_HANDLE_DBC, hdbc, sqlrc, &henv, &hdbc ) ;     

    sqlrc = SQLFreeHandle( SQL_HANDLE_ENV,  henv ) ;

    return( SQL_SUCCESS ) ;

}                            /* end main */
