-- This is a CLP script that creates an SQL procedure.
-- To create the SQL procedure using this script, perform the following steps:
-- 1. connect to the database
-- 2. issue the command "db2 -td@ -vf <script-name>"
--    where <script-name> represents the name of this script
--
-- To call this SQL procedure from the command line, perform the following steps:
-- 1. connect to the database
-- 2. issue the following command:
--    db2 "CALL median_result_set (20000)"
--
-- The sample "rsultset.c" demonstrates how to call this SQL procedure using
-- a CLI client application.

CREATE PROCEDURE median_result_set 
-- Declare medianSalary as INOUT so it can be used in DECLARE CURSOR
(INOUT medianSalary DOUBLE)
RESULT SETS 2
LANGUAGE SQL 
BEGIN 
   DECLARE v_numRecords INT DEFAULT 1;
   DECLARE v_counter INT DEFAULT 0;

   DECLARE c1 CURSOR FOR 
     SELECT CAST(salary AS DOUBLE) FROM staff 
     ORDER BY salary;

   -- use WITH RETURN in DECLARE CURSOR to return a result set
   DECLARE c2 CURSOR WITH RETURN FOR 
     SELECT name, job, CAST(salary AS DOUBLE) 
     FROM staff 
     WHERE salary > medianSalary
     ORDER BY salary;

   -- you can return as many result sets as you like, just
   -- ensure that the exact number is declared in the RESULT SETS
   -- clause of the CREATE PROCEDURE statement

   -- use WITH RETURN in DECLARE CURSOR to return another result set
   DECLARE c3 CURSOR WITH RETURN FOR
     SELECT name, job, CAST(salary AS DOUBLE)
     FROM staff
     WHERE salary < medianSalary
     ORDER BY SALARY DESC;

   DECLARE CONTINUE HANDLER FOR NOT FOUND
     SET medianSalary = 6666; 

   -- initialize OUT parameter
   SET medianSalary = 0;

   SELECT COUNT(*) INTO v_numRecords FROM STAFF;

   OPEN c1;
   WHILE v_counter < (v_numRecords / 2 + 1) DO
     FETCH c1 INTO medianSalary;
     SET v_counter = v_counter + 1;
   END WHILE;
   CLOSE c1;

   -- return 1st result set, do not CLOSE cursor
   OPEN c2;
  
   -- return 2nd result set, do not CLOSE cursor
   OPEN c3;
END @
