-- This is a CLP script that creates a set of SQL procedures.
-- To run this script from the CLP, perform the following steps:
-- 1. connect to the database
-- 2. issue the command "db2 -td@ -vf <script-name>"
--    where <script-name> represents the name of this script

CREATE PROCEDURE OUT_LANGUAGE (OUT procedureLanguage CHAR(8))
DYNAMIC RESULT SETS 0
LANGUAGE SQL 
READS SQL DATA
BEGIN
   SELECT language INTO procedureLanguage
      FROM sysibm.sysprocedures
      WHERE procname = 'OUT_LANGUAGE';
END @

CREATE PROCEDURE OUT_PARAM (OUT medianSalary DOUBLE, OUT errorCode INTEGER, OUT errorLabel CHAR(32))
DYNAMIC RESULT SETS 0
LANGUAGE SQL 
MODIFIES SQL DATA
BEGIN 
  DECLARE SQLCODE INTEGER DEFAULT 0;
  DECLARE v_numRecords INT DEFAULT 1;
  DECLARE v_counter INT DEFAULT 0;

  DECLARE c1 CURSOR FOR 
    SELECT CAST(salary AS DOUBLE) FROM staff 
    ORDER BY salary;

  DECLARE EXIT HANDLER FOR SQLEXCEPTION, SQLWARNING, NOT FOUND
    SET errorCode = SQLCODE; 

  -- If every statement succeeds, the EXIT handler will not set
  -- the errorCode parameter, so initialize the parameter to 0
  SET errorCode = 0;

  -- initialize OUT parameter
  SET medianSalary = 0;

  SET errorLabel = 'SELECT COUNT';
  SELECT COUNT(*) INTO v_numRecords FROM staff;

  OPEN c1;
  SET errorLabel = 'OPEN CURSOR';
  WHILE v_counter < (v_numRecords / 2 + 1) DO
    SET errorLabel = 'FETCH';
    FETCH c1 INTO medianSalary;
    SET v_counter = v_counter + 1;
  END WHILE;
  SET errorLabel = 'CLOSE CURSOR';
  CLOSE c1;
END @

CREATE PROCEDURE IN_PARAMS (IN lowsal DOUBLE, IN medsal DOUBLE, IN highsal DOUBLE, IN department CHAR(3), OUT errorCode INTEGER, OUT errorLabel CHAR(32))
DYNAMIC RESULT SETS 0
LANGUAGE SQL 
MODIFIES SQL DATA
BEGIN
  DECLARE SQLCODE INTEGER DEFAULT 0;
  DECLARE v_firstnme VARCHAR(12);
  DECLARE v_midinit CHAR(1);
  DECLARE v_lastname VARCHAR(15);
  DECLARE v_salary DOUBLE;
  DECLARE at_end SMALLINT DEFAULT 0;

  DECLARE c1 CURSOR FOR
    SELECT firstnme, midinit, lastname, CAST(salary AS DOUBLE)
    FROM employee
    WHERE workdept = department 
    FOR UPDATE OF salary;

  DECLARE CONTINUE HANDLER FOR NOT FOUND
    SET at_end = 1;
  DECLARE EXIT HANDLER FOR SQLEXCEPTION, SQLWARNING
    SET errorCode = SQLCODE; 

  -- If every statement succeeds, the EXIT handler will not set
  -- the errorCode parameter, so initialize the parameter to 0
  SET errorCode = 0;

  -- initialize OUT parameter
  SET errorLabel = 'OPEN CURSOR';
  OPEN c1;
  SET errorLabel = 'FIRST FETCH';
  FETCH c1 INTO v_firstnme, v_midinit, v_lastname, v_salary;
  WHILE (at_end = 0) DO
    IF (lowsal > v_salary) THEN
      UPDATE employee
      SET salary = lowsal
      WHERE CURRENT OF c1;
    ELSEIF (medsal > v_salary) THEN
      UPDATE employee
      SET salary = medsal
      WHERE CURRENT OF c1;
    ELSEIF (highsal > v_salary) THEN
      UPDATE employee
      SET salary = highsal
      WHERE CURRENT OF c1;
    ELSE UPDATE employee
      SET salary = salary * 1.10
      WHERE CURRENT OF c1;
    END IF;
    SET errorLabel = 'FETCH IN WHILE LOOP';
    FETCH c1 INTO v_firstnme, v_midinit, v_lastname, v_salary;
  END WHILE;
  SET errorLabel = 'CLOSE CURSOR';
  CLOSE c1;
END @

CREATE PROCEDURE INOUT_PARAM (INOUT medianSalary DOUBLE, OUT errorCode INTEGER, OUT errorLabel CHAR(32))
DYNAMIC RESULT SETS 0
LANGUAGE SQL 
MODIFIES SQL DATA
BEGIN 
  DECLARE SQLSTATE CHAR(5) DEFAULT '00000';
  DECLARE SQLCODE INTEGER DEFAULT 0;
  DECLARE v_medianSalary DOUBLE DEFAULT 0;
  DECLARE v_numRecords INT DEFAULT 1;
  DECLARE v_counter INT DEFAULT 0;

  DECLARE c1 CURSOR FOR 
    SELECT CAST(salary AS DOUBLE) FROM staff 
    WHERE salary > medianSalary
    ORDER BY salary;
  DECLARE EXIT HANDLER FOR SQLEXCEPTION, SQLWARNING, NOT FOUND
    SET errorCode = SQLCODE; 

  SET errorLabel = 'SELECT COUNT';
  SELECT COUNT(*) INTO v_numRecords FROM staff WHERE salary > medianSalary;

  SET errorLabel = 'OPEN CURSOR';
  OPEN c1;

  WHILE v_counter < (v_numRecords / 2 + 1) DO
    SET errorLabel = 'FETCH';
    FETCH c1 INTO v_medianSalary;
    SET medianSalary = v_medianSalary;
    SET v_counter = v_counter + 1;
  END WHILE;

  SET errorLabel = 'CLOSE CURSOR';
  CLOSE c1;
  SET errorCode = SQLCODE; 
END @

CREATE PROCEDURE ONE_RESULT_SET (IN salValue DOUBLE, OUT errorCode INTEGER)
DYNAMIC RESULT SETS 1
LANGUAGE SQL 
READS SQL DATA
BEGIN 
  DECLARE SQLCODE INTEGER DEFAULT 0;

  -- use WITH RETURN TO CLIENT in DECLARE CURSOR to always 
  -- return a result set to the client application
  DECLARE c1 CURSOR WITH RETURN TO CLIENT FOR 
    SELECT name, job, CAST(salary AS DOUBLE) 
    FROM staff 
    WHERE salary > salValue
    ORDER BY salary;

  -- in case of an exception, return SQLCODE to client 
  DECLARE EXIT HANDLER FOR SQLEXCEPTION, SQLWARNING, NOT FOUND
    SET errorCode = SQLCODE;  
 
  -- to return result set, do not CLOSE cursor
  OPEN c1;

  -- the EXIT handler ensures that we will not reach this point unless the 
  -- result set has results, so we can return a success code
  SET errorCode = SQLCODE;
END @

CREATE PROCEDURE RESULT_SET_CALLER (IN salValue DOUBLE, OUT errorCode INTEGER)
DYNAMIC RESULT SETS 1
LANGUAGE SQL 
READS SQL DATA
BEGIN 
  DECLARE SQLCODE INTEGER DEFAULT 0;

  -- use WITH RETURN TO CALLER in DECLARE CURSOR to always 
  -- return a result set to the calling application
  DECLARE c1 CURSOR WITH RETURN TO CALLER FOR 
    SELECT name, job, CAST(salary AS DOUBLE) 
    FROM staff 
    WHERE salary > salValue
    ORDER BY salary;

  -- in case of an exception, return SQLCODE to client 
  DECLARE EXIT HANDLER FOR SQLEXCEPTION, SQLWARNING, NOT FOUND
    SET errorCode = SQLCODE;  
 
  -- to return result set, do not CLOSE cursor
  OPEN c1;

  -- the EXIT handler ensures that we will not reach this point unless the 
  -- result set has results, so we can return a success code
  SET errorCode = SQLCODE;
END @

CREATE PROCEDURE TWO_RESULT_SETS (IN medianSalary DOUBLE, out errorCode INTEGER)
DYNAMIC RESULT SETS 2
LANGUAGE SQL 
READS SQL DATA
BEGIN
  DECLARE SQLCODE INTEGER DEFAULT 0;
  DECLARE nestCode INTEGER;
  DECLARE nestLabel CHAR(32);

  DECLARE r1 CURSOR WITH RETURN FOR
    SELECT name, job, CAST(salary AS DOUBLE)
    FROM staff
    WHERE salary > medianSalary
    ORDER BY salary; 

  DECLARE r2 CURSOR WITH RETURN FOR
    SELECT name, job, CAST(salary AS DOUBLE)
    FROM staff
    WHERE salary < medianSalary
    ORDER BY salary DESC; 

  DECLARE EXIT HANDLER FOR SQLEXCEPTION, SQLWARNING, NOT FOUND
    SET errorCode = SQLCODE; 

  OPEN r1;

  OPEN r2;

  -- the EXIT handler ensures that we will not reach this point unless the 
  -- result set has results, so we can return a success code
  SET errorCode = SQLCODE;

END @

CREATE PROCEDURE DECIMAL_TYPE (INOUT decimalInOut DECIMAL(10,2),
  OUT errorCode INTEGER, OUT errorLabel CHAR(32))
DYNAMIC RESULT SETS 0
LANGUAGE SQL 
READS SQL DATA
BEGIN
  DECLARE SQLCODE INTEGER DEFAULT 0;

  DECLARE CONTINUE HANDLER FOR SQLEXCEPTION, SQLWARNING, NOT FOUND
    SET errorCode = SQLCODE; 

  -- If every statement succeeds, the CONTINUE handler will not set
  -- the errorCode parameter, so initialize the parameter to 0
  SET errorCode = 0;

  SET errorLabel = 'IF DECIMAL';
  IF (decimalInOut = 0) THEN SET decimalInOut = 1;
  ELSE SET decimalInOut = decimalInOut / 2;
  END IF;

END @

CREATE PROCEDURE ALL_DATA_TYPES (INOUT smallInOut SMALLINT, 
  INOUT intInOut INTEGER, INOUT bigInOut BIGINT,
  INOUT realInOut REAL, INOUT doubleInOut DOUBLE,
  OUT charOut CHAR(1), OUT charsOut CHAR(15),
  OUT varcharOut VARCHAR(12), OUT dateOut DATE,
  OUT timeOut TIME, OUT errorCode INTEGER, OUT errorLabel CHAR(32))
DYNAMIC RESULT SETS 0
LANGUAGE SQL 
READS SQL DATA
BEGIN
   DECLARE SQLCODE INTEGER DEFAULT 0;

   DECLARE CONTINUE HANDLER FOR SQLEXCEPTION, SQLWARNING, NOT FOUND
     SET errorCode = SQLCODE; 

  -- If every statement succeeds, the CONTINUE handler will not set
  -- the errorCode parameter, so initialize the parameter to 0
  SET errorCode = 0;

  SET errorLabel = 'IF SMALLINT';
  IF (smallInOut = 0) THEN SET smallInOut = 1;
  ELSE SET smallInOut = smallInOut / 2;
  END IF;

  SET errorLabel = 'IF INTEGER';
  IF (intInOut = 0) THEN SET intInOut = 1;
  ELSE SET intInOut = intInOut / 2;
  END IF;

  SET errorLabel = 'IF BIGINT';
  IF (bigInOut = 0) THEN SET bigInOut = 1;
  ELSE SET bigInOut = bigInOut / 2;
  END IF;

  SET errorLabel = 'IF REAL';
  IF (realInOut = 0) THEN SET realInOut = 1;
  ELSE SET realInOut = realInOut / 2;
  END IF;

  SET errorLabel = 'IF DOUBLE';
  IF (doubleInOut = 0) THEN SET doubleInOut = 1;
  ELSE SET doubleInOut = doubleInOut / 2;
  END IF;

  SET errorLabel = 'SELECT midinit';
  SELECT midinit INTO charOut FROM employee WHERE empno = '000180';

  SET errorLabel = 'SELECT lastname';
  SELECT lastname INTO charsOut FROM employee WHERE empno = '000180';

  SET errorLabel = 'SELECT firstnme';
  SELECT firstnme INTO varcharOut FROM employee WHERE empno = '000180';

  SET errorLabel = 'VALUES CURRENT DATE';
  VALUES CURRENT DATE INTO dateOut;

  SET errorLabel = 'VALUES CURRENT TIME';
  VALUES CURRENT TIME INTO timeOut;

END @
